Crate kcr_config_karmada_io

Crate kcr_config_karmada_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the config.karmada.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

config.karmada.io/v1alpha1

  • ResourceInterpreterCustomization
  • ResourceInterpreterWebhookConfiguration

Modules

v1alpha1